pub struct NetworkEventHandle { /* private fields */ }Expand description
Network Event Handle
Lightweight handle for sending network events and receiving processing results.
Created before ActrNode::start() to bridge platform network events.
Implementations
Sourceimpl NetworkEventHandle
impl NetworkEventHandle
Sourcepub fn new(event_tx: Sender<NetworkEventRequest>) -> Self
pub fn new(event_tx: Sender<NetworkEventRequest>) -> Self
Create a new NetworkEventHandle
Sourcepub fn new_with_result_timeout(
event_tx: Sender<NetworkEventRequest>,
result_timeout: Duration,
) -> Self
pub fn new_with_result_timeout( event_tx: Sender<NetworkEventRequest>, result_timeout: Duration, ) -> Self
Create a new NetworkEventHandle with a custom result timeout.
Production bindings use NetworkEventHandle::new. Tests can use this
constructor to verify bounded waiting without sleeping for the full
binding timeout.
Sourcepub async fn handle_network_path_changed(
&self,
snapshot: NetworkSnapshot,
) -> Result<NetworkEventResult, String>
pub async fn handle_network_path_changed( &self, snapshot: NetworkSnapshot, ) -> Result<NetworkEventResult, String>
Handle full network path changes.
Sourcepub async fn handle_app_lifecycle_changed(
&self,
state: AppLifecycleState,
) -> Result<NetworkEventResult, String>
pub async fn handle_app_lifecycle_changed( &self, state: AppLifecycleState, ) -> Result<NetworkEventResult, String>
Handle app lifecycle changes.
Sourcepub async fn cleanup_connections(
&self,
reason: CleanupReason,
) -> Result<NetworkEventResult, String>
pub async fn cleanup_connections( &self, reason: CleanupReason, ) -> Result<NetworkEventResult, String>
Proactively clean up all connections with a reason. This never reconnects.
Sourcepub async fn force_reconnect(
&self,
reason: ReconnectReason,
) -> Result<NetworkEventResult, String>
pub async fn force_reconnect( &self, reason: ReconnectReason, ) -> Result<NetworkEventResult, String>
Force cleanup and reconnect.