pub struct NetworkTransportFlags {
pub wifi: bool,
pub cellular: bool,
pub ethernet: bool,
pub vpn: bool,
pub other: bool,
}Expand description
Active network transport flags. Multiple flags can be true at the same time.
Fields
wifi: boolcellular: boolethernet: boolvpn: boolother: boolTrait Implementations
Sourceimpl Clone for NetworkTransportFlags
impl Clone for NetworkTransportFlags
Sourcefn clone(&self) -> NetworkTransportFlags
fn clone(&self) -> NetworkTransportFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NetworkTransportFlags
Sourceimpl Debug for NetworkTransportFlags
impl Debug for NetworkTransportFlags
Sourceimpl Default for NetworkTransportFlags
impl Default for NetworkTransportFlags
Sourcefn default() -> NetworkTransportFlags
fn default() -> NetworkTransportFlags
Returns the “default value” for a type. Read more
impl Eq for NetworkTransportFlags
Sourceimpl Hash for NetworkTransportFlags
impl Hash for NetworkTransportFlags
Sourceimpl PartialEq for NetworkTransportFlags
impl PartialEq for NetworkTransportFlags
Sourcefn eq(&self, other: &NetworkTransportFlags) -> bool
fn eq(&self, other: &NetworkTransportFlags) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NetworkTransportFlags