Module prelude

Module prelude 

Convenience prelude module

Re-exports commonly used types and traits for quick imports:

use actr_hyper::prelude::*;

Re-exports

pub use crate::verify::ChainTrust;
pub use crate::verify::RegistryTrust;
pub use crate::verify::StaticTrust;
pub use crate::verify::TrustProvider;
pub use crate::Attached;
pub use crate::Hyper;
pub use crate::Init;
pub use crate::Node;
pub use crate::Registered;
pub use crate::storage::ActorStore;
pub use crate::HyperConfig;
pub use crate::HyperError;
pub use crate::actr_ref::ActrRef;
pub use crate::wire::webrtc::AuthConfig;
pub use crate::wire::webrtc::AuthType;
pub use crate::wire::webrtc::DisconnectReason;
pub use crate::wire::webrtc::ReconnectConfig;
pub use crate::wire::webrtc::SignalingClient;
pub use crate::wire::webrtc::SignalingConfig;
pub use crate::wire::webrtc::SignalingEvent;
pub use crate::wire::webrtc::SignalingStats;
pub use crate::transport::NetworkError;
pub use crate::transport::NetworkResult;

Modules

broadcast
A multi-producer, multi-consumer broadcast queue. Each sent value is seen by all consumers.
mpsc
A multi-producer, single-consumer queue for sending values between asynchronous tasks.
oneshot
A one-shot channel is used for sending a single message between asynchronous tasks. The channel function is used to create a Sender and Receiver handle pair that form the channel.

Macros

debug
Constructs an event at the debug level.
error
Constructs an event at the error level.
info
Constructs an event at the info level.
trace
Constructs an event at the trace level.
warn
Constructs an event at the warn level.

Structs

ActrId
DateTime
ISO 8601 combined date and time with time zone.
Duration
A Duration type to represent a span of time, typically used for system timeouts.
Instant
A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.
MailboxStats
Mailbox statistics
MediaSample
Media sample data from WebRTC native track
MessageRecord
Message record retrieved from the queue
Mutex
An asynchronous Mutex-like type.
PackageManifest
Package manifest, parsed from manifest.toml inside .actr package.
RwLock
An asynchronous reader-writer lock.
Utc
The UTC time zone. This is the most efficient time zone when you don’t need the local time. It is also used as an offset (which is also a dummy type).
Uuid
A Universally Unique Identifier (UUID).
VerifiedPackage
Result of a successful package verification.
WebRtcConfig
WebRTC configuration

Enums

ActrError
Top-level framework error, returned to all callers.
Dest
Destination identifier
MediaType
Media type enum
MessagePriority
Message priority
MessageStatus
Message processing status

Traits

AnyhowContext
Provides the context method for Result.
Context
Actor execution context interface.
Mailbox
Mailbox interface - defines core operations for message persistence
Workload
Workload — Executable Actor workload

Functions

sleep
Waits until duration has elapsed.
timeout
Requires a Future to complete before the specified duration has elapsed.

Type Aliases

ActorResult
Result type for actor RPC calls.
AnyhowResult
Result<T, Error>

Attribute Macros

async_trait