pub struct PackageManifest {
pub manufacturer: String,
pub name: String,
pub version: String,
pub binary: BinaryEntry,
pub signature_algorithm: String,
pub signing_key_id: Option<String>,
pub resources: Vec<ResourceEntry>,
pub proto_files: Vec<ProtoFileEntry>,
pub lock_file: Option<LockFileEntry>,
pub metadata: ManifestMetadata,
}Expand description
Package manifest, parsed from manifest.toml inside .actr package.
Fields
manufacturer: Stringname: Stringversion: Stringbinary: BinaryEntrysignature_algorithm: Stringsigning_key_id: Option<String>ID of the public key used for signing (allows key rotation and lookup of historical keys).
resources: Vec<ResourceEntry>proto_files: Vec<ProtoFileEntry>Proto files included in the package for service API definition.
lock_file: Option<LockFileEntry>Optional workload dependency lock file packaged with the workload.
metadata: ManifestMetadataImplementations