pub struct MfrCertCache { /* private fields */ }Expand description
Production mode MFR Ed25519 public key cache
Fetches manufacturer public keys on demand from the AIS endpoint, cache TTL defaults to 1 hour.
Shared across tasks via Arc<MfrCertCache>.
Implementations
Sourceimpl MfrCertCache
impl MfrCertCache
pub fn new(ais_endpoint: impl Into<String>) -> Arc<Self> ⓘ
Sourcepub fn get_from_cache(
&self,
manufacturer: &str,
key_id: Option<&str>,
) -> Option<VerifyingKey>
pub fn get_from_cache( &self, manufacturer: &str, key_id: Option<&str>, ) -> Option<VerifyingKey>
Used in RegistryTrust::verify_package synchronous path;
caller must ensure the cache has been warmed via get_or_fetch beforehand.
Sourcepub async fn get_or_fetch(
&self,
manufacturer: &str,
key_id: Option<&str>,
) -> Result<VerifyingKey, HyperError>
pub async fn get_or_fetch( &self, manufacturer: &str, key_id: Option<&str>, ) -> Result<VerifyingKey, HyperError>
Get the Ed25519 verifying key for the specified manufacturer
Reads from cache first (if not expired); on miss, fetches from AIS and updates cache.