pub struct ActrRef { /* private fields */ }Expand description
ActrRef - Lightweight reference to a running Actor
This is the primary handle returned by ActrNode::start().
Implementations
Sourceimpl ActrRef
impl ActrRef
Sourcepub async fn call<R: RpcRequest>(&self, request: R) -> ActorResult<R::Response>
pub async fn call<R: RpcRequest>(&self, request: R) -> ActorResult<R::Response>
Call the local workload with a typed RPC request.
Convenience wrapper around app_context().call(&Dest::Local, request).
Use this from app-side code to invoke the local guest workload.
Sourcepub async fn call_remote<R: RpcRequest>(
&self,
target: ActrId,
request: R,
) -> ActorResult<R::Response>
pub async fn call_remote<R: RpcRequest>( &self, target: ActrId, request: R, ) -> ActorResult<R::Response>
Call a remote actor directly with a typed RPC request.
Convenience wrapper around app_context().call(&Dest::Actor(target), request).
Use this when the client has no local guest workload and calls the remote actor directly.
Sourcepub async fn discover_route_candidates(
&self,
target_type: &ActrType,
count: usize,
) -> ActorResult<Vec<ActrId>>
pub async fn discover_route_candidates( &self, target_type: &ActrType, count: usize, ) -> ActorResult<Vec<ActrId>>
Discover route candidates for the given actor type.
Returns up to count actor IDs registered under target_type.
Convenience wrapper for app-side discovery without holding a RuntimeContext.
Note: The signaling protocol currently returns one candidate per request.
This method will make up to count requests to collect multiple unique candidates.
Sourcepub async fn app_context(&self) -> RuntimeContext
pub async fn app_context(&self) -> RuntimeContext
Create an application-side runtime context bound to this running actor.
Sourcepub fn shutdown(&self)
pub fn shutdown(&self)
Trigger Actor shutdown
This signals the Actor to stop, but does not wait for completion.
Use wait_for_shutdown() to wait for cleanup to finish.
Sourcepub async fn wait_for_shutdown(&self)
pub async fn wait_for_shutdown(&self)
Wait for Actor to fully shutdown
This waits for the shutdown signal to be triggered.
All background tasks will be aborted when the last ActrRef is dropped.
Sourcepub fn is_shutting_down(&self) -> bool
pub fn is_shutting_down(&self) -> bool
Check if Actor is shutting down
Sourcepub async fn wait_for_ctrl_c_and_shutdown(self) -> ActorResult<()>
pub async fn wait_for_ctrl_c_and_shutdown(self) -> ActorResult<()>