pub struct AisClient { /* private fields */ }Expand description
AIS HTTP client
Encapsulates the logic for sending protobuf requests to the AIS /register endpoint.
All requests use application/x-protobuf encoding.
Implementations
Sourceimpl AisClient
impl AisClient
Sourcepub fn new(endpoint: impl Into<String>) -> Self
pub fn new(endpoint: impl Into<String>) -> Self
Create a new AIS client
endpoint is the AIS base URL, e.g. "http://ais.example.com:8080".
Sourcepub fn with_realm_secret(self, secret: impl Into<String>) -> Self
pub fn with_realm_secret(self, secret: impl Into<String>) -> Self
Set the realm secret for authentication
Sourcepub async fn register_with_manifest(
&self,
req: RegisterRequest,
) -> Result<RegisterResponse, HyperError>
pub async fn register_with_manifest( &self, req: RegisterRequest, ) -> Result<RegisterResponse, HyperError>
Initial registration: authenticate with MFR manifest
Sends a RegisterRequest (containing manifest_raw + mfr_signature), receives a RegisterResponse. On initial registration, AIS returns a PSK in the response for subsequent renewals.
Sourcepub async fn register_with_psk(
&self,
req: RegisterRequest,
) -> Result<RegisterResponse, HyperError>
pub async fn register_with_psk( &self, req: RegisterRequest, ) -> Result<RegisterResponse, HyperError>
Renewal registration: authenticate with PSK
Sends a RegisterRequest (containing psk_token), receives a RegisterResponse with a new credential.
Sourcepub async fn register_linked(
&self,
req: RegisterRequest,
) -> Result<RegisterResponse, HyperError>
pub async fn register_linked( &self, req: RegisterRequest, ) -> Result<RegisterResponse, HyperError>
Linked registration: authenticate with realm authorization.
Sends a RegisterRequest marked as linked source mode. AIS authorizes it using the realm secret header instead of MFR package identity.