Lifecycle management layer (non-architectural layer)
Responsible for Actor system lifecycle management:
node::Inner: internal running-state struct used byNode<S>/ActrRef.
Structs
- Connection
Supervisor - Pure decision state for a settled connection event batch.
- Credential
State - Credential state for shared access between tasks
- Debounce
Config - Debounce configuration
- Default
Network Event Processor - Default network event processor implementation
- Network
Event Handle - Network Event Handle
- Network
Event Request - Network
Event Result - Network event processing result
- Network
Snapshot - Mobile network path snapshot.
- Network
Transport Flags - Active network transport flags. Multiple flags can be true at the same time.
Enums
- AppLifecycle
State - App lifecycle state relevant to connection recovery.
- Cleanup
Reason - Reason for a cleanup-only operation.
- Connection
Fact - Stable fact model used to converge mobile/network lifecycle events before execution.
- Network
Availability - Whether the platform currently has a usable network path.
- Network
Event - Network event type
- Network
Recovery Action - Final action selected from a settled batch of network events.
- Reconnect
Reason - Reason for a forced cleanup + restore operation.
Traits
- Network
Event Processor - Network event processor trait